from typing import Optional

from clowmdb.models import User
from sqlalchemy import select
from sqlalchemy.ext.asyncio import AsyncSession


class CRUDUser:
    @staticmethod
    async def get(db: AsyncSession, uid: str) -> Optional[User]:
        """
        Get a user by its UID.

        Parameters
        ----------
        db : sqlalchemy.ext.asyncio.AsyncSession.
            Async database session to perform query on.
        uid : str
            UID of a user.

        Returns
        -------
        user : clowmdb.models.User | None
            The user for the given UID if he exists, None otherwise
        """
        stmt = select(User).where(User.uid == uid)
        return await db.scalar(stmt)
