from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
from fastapi.middleware.gzip import GZipMiddleware
from fastapi.routing import APIRoute

from app.api.api import api_router
from app.api.miscellaneous_endpoints import miscellaneous_router
from app.core.config import settings

description = """
This is the workflow service from the CloWM Service.
"""


def custom_generate_unique_id(route: APIRoute) -> str:
    return f"{route.tags[-1]}-{route.name}"


app = FastAPI(
    title="CloWM Workflow Service",
    version="1.0.0",
    description=description,
    contact={
        "name": "Daniel Goebel",
        "url": "https://ekvv.uni-bielefeld.de/pers_publ/publ/PersonDetail.jsp?personId=223066601",
        "email": "dgoebel@techfak.uni-bielefeld.de",
    },
    generate_unique_id_function=custom_generate_unique_id,
    # license_info={"name": "MIT", "url": "https://mit-license.org/"},
    root_path=settings.API_PREFIX,
)

# CORS Settings for the API
app.add_middleware(
    CORSMiddleware,
    allow_origins=settings.BACKEND_CORS_ORIGINS,
    allow_credentials=False,
    allow_methods=["*"],
    allow_headers=["*"],
)

# Enable gzip compression for large responses
app.add_middleware(GZipMiddleware, minimum_size=500)

# Include all routes
app.include_router(api_router)
app.include_router(miscellaneous_router)
