from typing import Dict
from uuid import uuid4

from fastapi import status
from httpx import Response

from app.schemas.security import AuthzResponse


def handle_request(body: Dict[str, str]) -> Response:
    """
    Handle a request to the authorization service during testing.

    Parameters
    ----------
    body : Dict[str, str]
        Body of the request.

    Returns
    -------
    response : httpx.Response
        Mock response.
    """
    response_body = AuthzResponse(result=not request_admin_permission(body), decision_id=str(uuid4())).model_dump()
    return Response(status_code=status.HTTP_200_OK, json=response_body)


def request_admin_permission(body: Dict[str, str]) -> bool:
    """
    Helper function to determine if the authorization request needs the 'administrator' role.

    Parameters
    ----------
    body : Dict[str, str]
        Body of the request.

    Returns
    -------
    decision : bool
        Flag if the request needs the 'administrator' role
    """
    operation = body["operation"]
    checks = "any" in operation
    if "bucket_permission" in body["resource"]:
        checks = checks or "all" in operation
    return checks
